==> openshift-client-4.11.0-sources.jar: io/fabric8/openshift/client/dsl/internal/IngressControllerOperationsImpl.java <==

                
      

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableIngressController;
import io.fabric8.openshift.api.model.operator.v1.IngressController;
import io.fabric8.openshift.api.model.operator.v1.IngressControllerList;
import io.fabric8.openshift.api.model.operator.v1.DoneableIngressController;

import java.util.Map;
import java.util.TreeMap;


public class IngressControllerOperationsImpl extends OpenShiftOperation<IngressController, IngressControllerList, DoneableIngressController, Resource<IngressController, DoneableIngressController>> {

  public IngressControllerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public IngressControllerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("ingresscontrollers"));
    this.type = IngressController.class;
    this.listType = IngressControllerList.class;
    this.doneableType = DoneableIngressController.class;
  }

  public IngressControllerOperationsImpl newInstance(OperationContext context) {
    return new IngressControllerOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> openshift-client-5.3.2-sources.jar: io/fabric8/openshift/client/dsl/internal/IngressControllerOperationsImpl.java <==

                            
      

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.IngressController;
import io.fabric8.openshift.api.model.operator.v1.IngressControllerBuilder;
import io.fabric8.openshift.api.model.operator.v1.IngressControllerList;

import java.util.Map;
import java.util.TreeMap;


public class IngressControllerOperationsImpl extends OpenShiftOperation<IngressController, IngressControllerList, Resource<IngressController>> {

  public IngressControllerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public IngressControllerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("ingresscontrollers"));
    this.type = IngressController.class;
    this.listType = IngressControllerList.class;
  }

  public IngressControllerOperationsImpl newInstance(OperationContext context) {
    return new IngressControllerOperationsImpl(context);
  }

  @Override
  public IngressController edit(Visitor... visitors) {
    return patch(new IngressControllerBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
